@@ -605,7 +605,7 @@ struct server_list *create_server_list(char *errbuf, int n_errbuf)
   struct utsname un;
 #endif 
 
-  urlpath = my_lookup_httpd(metaname, &metaport, METALIST_ADDR);//metaserver);
+  urlpath = my_lookup_httpd(metaname, &metaport, metaserver);
   if (!urlpath) {
     (void) mystrlcpy(errbuf, _("Invalid $http_proxy or metaserver value, must "
                               "start with 'http://'"), n_errbuf);
@@ -822,13 +822,13 @@ int begin_lanserver_scan(void)
   Listens for UDP packets broadcasted from a server that responded
   to the request-packet sent from the client. 
 **************************************************************************/
-struct server_list *get_lan_server_list(void) {
-
-# if defined(__VMS) && !defined(_DECC_V4_SOURCE)
-    size_t fromlen;
-# else
-    int fromlen;
-# endif
+struct server_list *get_lan_server_list(void)
+{
+#ifdef HAVE_SOCKLEN_T
+  socklen_t fromlen;
+#else
+  int fromlen;
+#endif
   union my_sockaddr fromend;
   struct hostent *from;
   char msgbuf[128];
