@@ -10,13 +10,14 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 ***********************************************************************/
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <assert.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -64,9 +65,7 @@ static Widget help_title;
 static Widget help_improvement_cost, help_improvement_cost_data;
 static Widget help_improvement_upkeep, help_improvement_upkeep_data;
 static Widget help_improvement_req, help_improvement_req_data;
-static Widget help_improvement_variant, help_improvement_variant_data;
 static Widget help_wonder_obsolete, help_wonder_obsolete_data;
-static Widget help_wonder_variant, help_wonder_variant_data;
 
 static Widget help_tech_tree;
 static Widget help_tree_viewport;
@@ -90,6 +89,9 @@ static Widget help_terrain_irrigation_result_time, help_terrain_irrigation_resul
 static Widget help_terrain_mining_result_time, help_terrain_mining_result_time_data;
 static Widget help_terrain_transform_result_time, help_terrain_transform_result_time_data;
 
+/* HACK: we use a static string for convenience. */
+static char long_buffer[64000];
+
 static void create_help_page(enum help_page_type type);
 
 static void help_close_command_callback(Widget w, XtPointer client_data, 
@@ -403,18 +405,7 @@ static void create_help_page(enum help_page_type type)
 				labelWidgetClass, 
 				help_right_form,
 				NULL);
-      help_improvement_variant =
-	I_L(XtVaCreateManagedWidget("helpimprvariant", 
-				    labelWidgetClass, 
-				    help_right_form,
-				    NULL));
-      help_improvement_variant_data =
-	XtVaCreateManagedWidget("helpimprvariantdata",
-				labelWidgetClass, 
-				help_right_form,
-				NULL);
-    }
-    else {
+    } else {
       help_wonder_obsolete =
 	I_L(XtVaCreateManagedWidget("helpwonderobsolete", 
 				    labelWidgetClass, 
@@ -425,16 +416,6 @@ static void create_help_page(enum help_page_type type)
 				labelWidgetClass, 
 				help_right_form,
 				NULL);
-      help_wonder_variant =
-	I_L(XtVaCreateManagedWidget("helpwondervariant", 
-				    labelWidgetClass, 
-				    help_right_form,
-				    NULL));
-      help_wonder_variant_data =
-	XtVaCreateManagedWidget("helpwondervariantdata",
-				labelWidgetClass, 
-				help_right_form,
-				NULL);
     }
 
     XtVaGetValues(help_improvement_req, XtNy, &ay, XtNheight, &ah, NULL);
@@ -762,18 +743,16 @@ static void create_help_page(enum help_page_type type)
 static void help_update_improvement(const struct help_item *pitem,
 				    char *title, int which)
 {
-  char *buf = &long_buffer[0];
+  char buf[64000];
   
   create_help_page(HELP_IMPROVEMENT);
   
   if (which<game.num_impr_types) {
     struct impr_type *imp = &improvement_types[which];
-    sprintf(buf, "%d ", imp->build_cost);
+    sprintf(buf, "%d ", impr_build_shield_cost(which));
     xaw_set_label(help_improvement_cost_data, buf);
     sprintf(buf, "%d ", imp->upkeep);
     xaw_set_label(help_improvement_upkeep_data, buf);
-    sprintf(buf, "%d ", imp->variant);
-    xaw_set_label(help_improvement_variant_data, buf);
     if (imp->tech_req == A_LAST) {
       xaw_set_label(help_improvement_req_data, _("(Never)"));
     } else {
@@ -785,12 +764,11 @@ static void help_update_improvement(const struct help_item *pitem,
   else {
     xaw_set_label(help_improvement_cost_data, "0 ");
     xaw_set_label(help_improvement_upkeep_data, "0 ");
-    xaw_set_label(help_improvement_variant_data,"0 ");
     xaw_set_label(help_improvement_req_data, _("(Never)"));
     create_tech_tree(help_tech_tree, 0, A_LAST, 3);
   }
   set_title_topic(pitem);
-  helptext_improvement(buf, which, pitem->text);
+  helptext_building(buf, sizeof(buf), which, pitem->text);
   XtVaSetValues(help_text, XtNstring, buf, NULL);
 }
   
@@ -800,36 +778,37 @@ static void help_update_improvement(const struct help_item *pitem,
 static void help_update_wonder(const struct help_item *pitem,
 			       char *title, int which)
 {
-  char *buf = &long_buffer[0];
+  char buf[64000];
   
   create_help_page(HELP_WONDER);
 
   if (which<game.num_impr_types) {
     struct impr_type *imp = &improvement_types[which];
-    sprintf(buf, "%d ", imp->build_cost);
+    sprintf(buf, "%d ", impr_build_shield_cost(which));
     xaw_set_label(help_improvement_cost_data, buf);
-    sprintf(buf, "%d ", imp->variant);
-    xaw_set_label(help_wonder_variant_data, buf);
     if (imp->tech_req == A_LAST) {
       xaw_set_label(help_improvement_req_data, _("(Never)"));
     } else {
       xaw_set_label(help_improvement_req_data,
 		    advances[imp->tech_req].name);
     }
-    xaw_set_label(help_wonder_obsolete_data,
-		  advances[imp->obsolete_by].name);
+    if (tech_exists(imp->obsolete_by)) {
+      xaw_set_label(help_wonder_obsolete_data,
+		    advances[imp->obsolete_by].name);
+    } else {
+      xaw_set_label(help_wonder_obsolete_data, _("(Never)"));
+    }
     create_tech_tree(help_tech_tree, 0, imp->tech_req, 3);
   }
   else {
     /* can't find wonder */
     xaw_set_label(help_improvement_cost_data, "0 ");
-    xaw_set_label(help_wonder_variant_data, "0 ");
     xaw_set_label(help_improvement_req_data, _("(Never)"));
     xaw_set_label(help_wonder_obsolete_data, _("None"));
     create_tech_tree(help_tech_tree, 0, game.num_tech_types, 3); 
   }
   set_title_topic(pitem);
-  helptext_wonder(buf, which, pitem->text);
+  helptext_building(buf, sizeof(buf), which, pitem->text);
   XtVaSetValues(help_text, XtNstring, buf, NULL);
 }
 
@@ -844,7 +823,7 @@ static void help_update_unit_type(const struct help_item *pitem,
   create_help_page(HELP_UNIT);
   if (i<game.num_unit_types) {
     struct unit_type *utype = get_unit_type(i);
-    sprintf(buf, "%d ", utype->build_cost);
+    sprintf(buf, "%d ", unit_build_shield_cost(i));
     xaw_set_label(help_unit_cost_data, buf);
     sprintf(buf, "%d ", utype->attack_strength);
     xaw_set_label(help_unit_attack_data, buf);
@@ -923,7 +902,7 @@ static void help_update_tech(const struct help_item *pitem, char *title, int i)
 		get_unit_type(j)->name);
     } unit_type_iterate_end;
 
-    for(j=0; j<game.num_tech_types; ++j) {
+    for (j = 0; j < game.num_tech_types; j++) {
       if(i==advances[j].req[0]) {
 	if(advances[j].req[1]==A_NONE)
 	  sprintf(buf+strlen(buf), _("Allows %s.\n"), 
@@ -958,6 +937,7 @@ static void help_update_terrain(const struct help_item *pitem,
 				char *title, int i)
 {
   char *buf = &long_buffer[0];
+  struct tile_type *ptype = get_tile_type(i);
 
   create_help_page(HELP_TERRAIN);
   set_title_topic(pitem);
@@ -968,56 +948,56 @@ static void help_update_terrain(const struct help_item *pitem,
   if (i < T_COUNT)
     {
       sprintf (buf, "%d/%d.%d",
-	       tile_types[i].movement_cost,
-	       (int)(tile_types[i].defense_bonus/10), tile_types[i].defense_bonus%10);
+	       ptype->movement_cost,
+	       (int)(ptype->defense_bonus/10), ptype->defense_bonus%10);
       xaw_set_label (help_terrain_movement_defense_data, buf);
 
       sprintf (buf, "%d/%d/%d",
-	       tile_types[i].food,
-	       tile_types[i].shield,
-	       tile_types[i].trade);
+	       ptype->food,
+	       ptype->shield,
+	       ptype->trade);
       xaw_set_label (help_terrain_food_shield_trade_data, buf);
 
-      if (*(tile_types[i].special_1_name))
+      if (*(ptype->special_1_name))
 	{
 	  sprintf (buf, _("%s F/R/T:"),
-		   tile_types[i].special_1_name);
+		   ptype->special_1_name);
 	  xaw_set_label (help_terrain_special_1, buf);
 	  sprintf (buf, "%d/%d/%d",
-		   tile_types[i].food_special_1,
-		   tile_types[i].shield_special_1,
-		   tile_types[i].trade_special_1);
+		   ptype->food_special_1,
+		   ptype->shield_special_1,
+		   ptype->trade_special_1);
 	  xaw_set_label (help_terrain_special_1_data, buf);
 	} else {
 	  xaw_set_label (help_terrain_special_1, "");
 	  xaw_set_label (help_terrain_special_1_data, "");
 	}
 
-      if (*(tile_types[i].special_2_name))
+      if (*(ptype->special_2_name))
 	{
 	  sprintf (buf, _("%s F/R/T:"),
-		   tile_types[i].special_2_name);
+		   ptype->special_2_name);
 	  xaw_set_label (help_terrain_special_2, buf);
 	  sprintf (buf, "%d/%d/%d",
-		   tile_types[i].food_special_2,
-		   tile_types[i].shield_special_2,
-		   tile_types[i].trade_special_2);
+		   ptype->food_special_2,
+		   ptype->shield_special_2,
+		   ptype->trade_special_2);
 	  xaw_set_label (help_terrain_special_2_data, buf);
 	} else {
 	  xaw_set_label (help_terrain_special_2, "");
 	  xaw_set_label (help_terrain_special_2_data, "");
 	}
 
-      if (tile_types[i].road_trade_incr > 0)
+      if (ptype->road_trade_incr > 0)
 	{
 	  sprintf (buf, _("+%d Trade / %d"),
-		   tile_types[i].road_trade_incr,
-		   tile_types[i].road_time);
+		   ptype->road_trade_incr,
+		   ptype->road_time);
 	}
-      else if (tile_types[i].road_time > 0)
+      else if (ptype->road_time > 0)
 	{
 	  sprintf (buf, _("no extra / %d"),
-		   tile_types[i].road_time);
+		   ptype->road_time);
 	}
       else
 	{
@@ -1026,46 +1006,46 @@ static void help_update_terrain(const struct help_item *pitem,
       xaw_set_label (help_terrain_road_result_time_data, buf);
 
       strcpy (buf, _("n/a"));
-      if (tile_types[i].irrigation_result == i)
+      if (ptype->irrigation_result == i)
 	{
-	  if (tile_types[i].irrigation_food_incr > 0)
+	  if (ptype->irrigation_food_incr > 0)
 	    {
 	      sprintf (buf, _("+%d Food / %d"),
-		       tile_types[i].irrigation_food_incr,
-		       tile_types[i].irrigation_time);
+		       ptype->irrigation_food_incr,
+		       ptype->irrigation_time);
 	    }
 	}
-      else if (tile_types[i].irrigation_result != T_LAST)
+      else if (ptype->irrigation_result != T_NONE)
 	{
 	  sprintf (buf, "%s / %d",
-		   tile_types[tile_types[i].irrigation_result].terrain_name,
-		   tile_types[i].irrigation_time);
+		   get_tile_type(ptype->irrigation_result)->terrain_name,
+		   ptype->irrigation_time);
 	}
       xaw_set_label (help_terrain_irrigation_result_time_data, buf);
 
       strcpy (buf, _("n/a"));
-      if (tile_types[i].mining_result == i)
+      if (ptype->mining_result == i)
 	{
-	  if (tile_types[i].mining_shield_incr > 0)
+	  if (ptype->mining_shield_incr > 0)
 	    {
 	      sprintf (buf, _("+%d Res. / %d"),
-		       tile_types[i].mining_shield_incr,
-		       tile_types[i].mining_time);
+		       ptype->mining_shield_incr,
+		       ptype->mining_time);
 	    }
 	}
-      else if (tile_types[i].mining_result != T_LAST)
+      else if (ptype->mining_result != T_NONE)
 	{
 	  sprintf (buf, "%s / %d",
-		   tile_types[tile_types[i].mining_result].terrain_name,
-		   tile_types[i].mining_time);
+		   get_tile_type(ptype->mining_result)->terrain_name,
+		   ptype->mining_time);
 	}
       xaw_set_label (help_terrain_mining_result_time_data, buf);
 
-      if (tile_types[i].transform_result != T_LAST)
+      if (ptype->transform_result != T_NONE)
 	{
 	  sprintf (buf, "%s / %d",
-		   tile_types[tile_types[i].transform_result].terrain_name,
-		   tile_types[i].transform_time);
+		   get_tile_type(ptype->transform_result)->terrain_name,
+		   ptype->transform_time);
 	} else {
 	  strcpy (buf, _("n/a"));
 	}
@@ -1101,7 +1081,9 @@ static void help_update_dialog(const struct help_item *pitem)
 
   /* figure out what kind of item is required for pitem ingo */
 
-  for(top=pitem->topic; *top==' '; ++top);
+  for (top = pitem->topic; *top == ' '; top++) {
+    /* nothing */
+  }
 
   switch(pitem->type) {
   case HELP_IMPROVEMENT:
@@ -1155,7 +1137,7 @@ static int help_tree_destroy_children(Widget w)
 		XtNnumChildren, &cnt,
 		NULL);
 
-  for(; cnt>0; --cnt, ++children) {
+  for (; cnt > 0; cnt--, children++) {
     if(XtIsSubclass(*children, commandWidgetClass)) {
       Widget par;
       XtVaGetValues(*children, XtNtreeParent, &par, NULL);
