@@ -11,7 +11,10 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-#include <string.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>		/* getenv() */
 
 #include "connection.h"		/* MAX_LEN_CAPSTR */
@@ -70,17 +73,25 @@ const char * const our_capability = our_capability_internal;
  * are not directly related to the capability strings discussed here.)
  */
 
-#define CAPABILITY "+1.13.0 conn_info"
-  
-/* "+1.13.0" is protocol for 1.13.0 release.
-  
-   "conn_info" is sending the conn_id field. To preserve compatability
-   with old clients trying to connect this should persist across releases.
-*/
+/* +2.0 is the capability string for the 2.0.x release(s).
+ *
+ * "conn_ping_info" means the packet_conn_ping_info uses MAX_NUM_CONNECTIONS
+ * not MAX_NUM_PLAYERS.
+ *
+ * "username_info" means that the username is sent in the player_info packet
+ *
+ *   - No new manditory capabilities can be added to the release branch; doing
+ *     so would break network capability of supposedly "compatible" releases.
+ *
+ *   - Avoid adding a new manditory capbility to the development branch for
+ *     as long as possible.  We want to maintain network compatibility with
+ *     the stable branch for as long as possible.
+ */
+#define CAPABILITY "+2.0 conn_ping_info username_info new_hack"
 
 void init_our_capability(void)
 {
-  char *s;
+  const char *s;
 
   s = getenv("FREECIV_CAPS");
   if (!s) {
