@@ -63,7 +63,6 @@ static void package_player_info(struct player *plr,
                                 enum plr_info_level min_info_level);
 static Nation_Type_id pick_available_nation(Nation_Type_id *choices);
 static void tech_researched(struct player* plr);
-static bool choose_goal_tech(struct player *plr);
 static Tech_Type_id pick_random_tech(struct player *plr);
 static enum plr_info_level player_info_level(struct player *plr,
 					     struct player *receiver);
@@ -374,8 +373,9 @@ void found_new_tech(struct player *plr, int tech_found, bool was_discovery,
 
   if (tech_found == plr->research.researching && next_tech == A_NONE) {
     /* try to pick new tech to research */
+    Tech_Type_id next_tech = choose_goal_tech(plr);
 
-    if (choose_goal_tech(plr)) {
+    if (next_tech != A_UNSET) {
       notify_player_ex(plr, NULL, E_TECH_LEARNED,
 		       _("Game: Learned %s.  "
 			 "Our scientists focus on %s, goal is %s."),
@@ -581,9 +581,9 @@ void update_tech(struct player *plr, int bulbs)
 /**************************************************************************
 ...
 **************************************************************************/
-static bool choose_goal_tech(struct player *plr)
+Tech_Type_id choose_goal_tech(struct player *plr)
 {
-  int sub_goal;
+  Tech_Type_id sub_goal;
 
   if (plr->ai.control) {
     ai_next_tech_goal(plr);	/* tech-AI has been changed */
@@ -600,10 +600,9 @@ static bool choose_goal_tech(struct player *plr)
   }
 
   if (sub_goal != A_UNSET) {
-    plr->research.researching = sub_goal;
-    return TRUE;
+    choose_tech(plr, sub_goal);
   }
-  return FALSE;
+  return sub_goal;
 }
 
 /**************************************************************************
@@ -638,6 +637,21 @@ static Tech_Type_id pick_random_tech(struct player *plr)
   return A_NONE;
 }
 
+/****************************************************************************
+  Gives a player random tech, which he hasn't researched yet. Applies freecost
+  Returns the tech.
+****************************************************************************/
+Tech_Type_id give_random_free_tech(struct player* pplayer)
+{
+  Tech_Type_id tech;
+  
+  tech = pick_random_tech(pplayer);
+  do_free_cost(pplayer);
+  found_new_tech(pplayer, tech, FALSE, TRUE, A_NONE);
+  return tech;
+}
+
+
 /**************************************************************************
 ...
 **************************************************************************/
@@ -711,7 +725,7 @@ void init_tech(struct player *plr)
 
   /* Mark the reachable techs */
   update_research(plr);
-  if (!choose_goal_tech(plr)) {
+  if (choose_goal_tech(plr) == A_UNSET) {
     choose_random_tech(plr);
   }
 }
@@ -1431,6 +1445,10 @@ void notify_conn_ex(struct conn_list *dest, struct tile *ptile,
 void notify_conn(struct conn_list *dest, const char *format, ...) 
 {
   va_list args;
+
+  if (!dest) {
+    dest = &game.est_connections;
+  }
   va_start(args, format);
   vnotify_conn_ex(dest, NULL, E_NOEVENT, format, args);
   va_end(args);
